# TestRunAnalyticResultModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**count_group_by_status** | [**[TestRunGroupByStatusModel], none_type**](TestRunGroupByStatusModel.md) |  | [optional] 
**count_group_by_failure_class** | [**[TestRunGroupByFailureClassModel], none_type**](TestRunGroupByFailureClassModel.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


